@@ -66,6 +66,7 @@ import javax.xml.bind.annotation.XmlType;
  *     &lt;enumeration value="Number:Temperature"/&gt;
  *     &lt;enumeration value="Number:Time"/&gt;
  *     &lt;enumeration value="Number:Volume"/&gt;
+ *     &lt;enumeration value="Number:VolumePrice"/&gt;
  *     &lt;enumeration value="Number:VolumetricFlowRate"/&gt;
  *     &lt;enumeration value="Player"/&gt;
  *     &lt;enumeration value="Rollershutter"/&gt;
@@ -78,7 +79,7 @@ import javax.xml.bind.annotation.XmlType;
  */
 @XmlType(name = "itemTypeName")
 @XmlEnum
-@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-11-23T14:05:45Z")
+@Generated(value = "com.sun.tools.xjc.Driver", comments = "JAXB RI v2.3.7", date = "2025-12-22T14:42:29Z")
 public enum XmlItemTypeName {
 
     @XmlEnumValue("Call")
@@ -185,6 +186,8 @@ public enum XmlItemTypeName {
     NUMBER_TIME("Number:Time"),
     @XmlEnumValue("Number:Volume")
     NUMBER_VOLUME("Number:Volume"),
+    @XmlEnumValue("Number:VolumePrice")
+    NUMBER_VOLUME_PRICE("Number:VolumePrice"),
     @XmlEnumValue("Number:VolumetricFlowRate")
     NUMBER_VOLUMETRIC_FLOW_RATE("Number:VolumetricFlowRate"),
     @XmlEnumValue("Player")
